variable "AWS_ACCESS_KEY_ID" {}
variable "AWS_SECRET_ACCESS_KEY" {}
variable "KEY_NAME" {}
variable "PRIVATE_KEY_PATH" {}
variable "region" {
  default = "us-east-2"
}

terraform {
  required_providers {
    aws = {
      source = "hashicorp/aws"
      version = "~> 4.16"
    }
  }

  required_version = ">= 1.2.0"
}

provider "aws" {
  region = var.region
  access_key = var.AWS_ACCESS_KEY_ID
  secret_key = var.AWS_SECRET_ACCESS_KEY  
}

resource "aws_default_vpc" "default"{
}

resource "aws_security_group" "terra_example_security_group" {
  name = "terra_example_security_group"
  description = "open ports for ssh and http"
  vpc_id = aws_default_vpc.default.id
  
  ingress {
    from_port = 22
    to_port = 22
    protocol = "tcp"
    cidr_blocks = ["0.0.0.0/0"]
  }

  ingress {
    from_port = 80
    to_port = 80
    protocol = "tcp"
    cidr_blocks = ["0.0.0.0/0"]
  }
  
  egress {
    from_port   = 0
    to_port     = 0
    protocol    = "-1"
    cidr_blocks = ["0.0.0.0/0"]
  }
}

resource "aws_instance" "aws_ubuntu" {
  ami = "ami-0f3bafb503ed83c46"
  instance_type = "t2.micro"
  key_name = var.KEY_NAME
  user_data = file("userdata.sh")
  tags = {
    Name = "terra example"
  }
  security_groups = [
    aws_security_group.terra_example_security_group.name
  ]
}
